@@ -1,9 +1,12 @@
+package Task::Date::Holidays;
+
 use strict;
 use warnings;
+use vars qw($VERSION);
 use 5.006;
 
-package Task::Date::Holidays;
-$Task::Date::Holidays::VERSION = '0.07';
+$VERSION = '0.09';
+
 1;
 
 __END__
@@ -24,10 +27,6 @@ __END__
 
 Task::Date::Holidays - Work package for holiday modules in the Date::Holidays namespace
 
-=head1 VERSION
-
-version 0.07
-
 =head1 SYNOPSIS
 
     $ tar xvzf Task-Date-Holidays-0.01.tgz
@@ -44,17 +43,15 @@ version 0.07
 
 =head1 DESCRIPTION
 
-THis module is intended to provide an easy way to install all of the Date::Holidays::* distributions.
+THis distribution is intended to provide an easy way to install all of the Date::Holidays::* distributions.
 
-Bundling these makes it easier for me personally, in the work related to maintaining L<Date::Holidays>.
+Bundling these makes it easier for me, in the work related to maintaining L<Date::Holidays>.
 
-If your distribution is missing, let me know or fork and send me a pull request or just let me know.
+If your distribution is missing send me a pull request or just let me know.
 
-If you want to provide a distribution to the namespace, please see Date::Holidays for more documentation on this.
+If you want to provide a distribution to the namespace, please see Date::Holidays for more information.
 
-Do note that because a distribution is listed in the below list, does not necessarily make it compatible with the
-Date::Holidays API. Distributions listed here indicate that a given distribution is either compatible or
-being considered for inclusion.
+Do note that because a distribution is listed in the below list, does not necessarily make it compatible with the Date::Holidays API. Distributions listed here indicate that a given distribution is either compatible or being considered for inclusion.
 
 Please see L<Date::Holidays>
 
@@ -66,6 +63,8 @@ Please see L<Date::Holidays>
 
 =item * L<Date::Holidays::AU>
 
+=item * L<Date::Holidays::AW>
+
 =item * L<Date::Holidays::BR>
 
 =item * L<Date::Holidays::BY>
@@ -90,6 +89,10 @@ Please see L<Date::Holidays>
 
 =item * L<Date::Holidays::KR>
 
+=item * L<Date::Holidays::KZ>
+
+=item * L<Date::Holidays::NL>
+
 =item * L<Date::Holidays::NO>
 
 =item * L<Date::Holidays::NZ>
@@ -102,6 +105,8 @@ Please see L<Date::Holidays>
 
 =item * L<Date::Holidays::SK>
 
+=item * L<Date::Holidays::UA>
+
 =item * L<Date::Holidays::UK>
 
 =item * L<Date::Holidays::USFederal>
@@ -130,7 +135,7 @@ No special configuration or environment is required.
 
 =head1 ISSUE REPORTING
 
-Please report any bugs or feature requests either using Github
+Please report any bugs or feature requests using Github
 
 =over
 
@@ -140,7 +145,7 @@ Please report any bugs or feature requests either using Github
 
 =head1 AUTHOR
 
-Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
+Jonas B., (jonasbn) - C<< <jonasbn@cpan.org> >>
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -156,8 +161,8 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Task-Date-Holidays and related modules are (C) by Jonas B. Nielsen, (jonasbn)
-2014-2017
+Task-Date-Holidays and related modules are (C) by Jonas B., (jonasbn)
+2014-2020
 
 Task-Date-Holidays and related modules are released under the Artistic License 2.0
 
